{% extends "admin/base_site.html" %}
{% load i18n %}

{% block title %}{% trans "Load data" %} {{ block.super }}{% endblock %}

{% block extrahead %}
    {{ block.super }}
    <script type="text/javascript" src="{% url 'admin:jsi18n' %}"></script>
    {{ form.media.js }}
{% endblock %}

{% block extrastyle %}
  {{ block.super }}
  {{ form.media.css }}
{% endblock %}

{% block bodyclass %}change-form{% endblock %}

{% block breadcrumbs %}
<div class="breadcrumbs">
  <a href="{% url 'admin:index' %}">{% trans "Home" %}</a> &rsaquo;
  {% trans "Load data" %}
</div>
{% endblock %}

{% block content %}
<div id="content-main">
<form enctype="multipart/form-data" method="post" action=".">
  {% csrf_token %}
  <h1>{% trans "Load data" %}</h1>
  <div class="system-message">
    <p class="description">
      {% trans 'Existing items with same <strong>primary key</strong> will be overwritten.' %}
    </p>
  </div>
  {% if form.errors %}
  <p class="errornote">
    {% if form.errors|length == 1 %}
      {% trans "Please correct the error below." %}
    {% else %}
      {% trans "Please correct the errors below." %}
    {% endif %}
  </p>
  {{ form.non_field_errors }}
  {% endif %}
  {% for fieldset in adminform %}
    {% include "admin/includes/fieldset.html" %}
  {% endfor %}
  <div class="submit-row">
    <input class="default" type="submit" name="_load" value="{% trans "Load" %}" />
  </div>
</form>
</div>
{% endblock %}
